Index: kernel/generic/src/proc/thread.c
===================================================================
--- kernel/generic/src/proc/thread.c	(revision 174156fd1cf321a6363777352073d05829467b2f)
+++ kernel/generic/src/proc/thread.c	(revision 91a8f837283629418f6b227ac9232dd63901abf2)
@@ -356,5 +356,5 @@
 	    (uintptr_t) thread->kstack, STACK_SIZE);
 
-	the_initialize((the_t *) thread->kstack);
+	current_initialize((current_t *) thread->kstack);
 
 	ipl_t ipl = interrupts_disable();

Index: kernel/generic/src/proc/scheduler.c
===================================================================
--- kernel/generic/src/proc/scheduler.c	(revision 174156fd1cf321a6363777352073d05829467b2f)
+++ kernel/generic/src/proc/scheduler.c	(revision 91a8f837283629418f6b227ac9232dd63901abf2)
@@ -363,10 +363,10 @@
 
 	/*
 	 * Through the 'THE' structure, we keep track of THREAD, TASK, CPU, AS
 	 * and preemption counter. At this point THE could be coming either
 	 * from THREAD's or CPU's stack.
 	 *
 	 */
-	the_copy(THE, (the_t *) CPU->stack);
+	current_copy(CURRENT, (current_t *) CPU->stack);
 
 	/*
@@ -548,5 +548,5 @@
 	 * thread's stack.
 	 */
-	the_copy(THE, (the_t *) THREAD->kstack);
+	current_copy(CURRENT, (current_t *) THREAD->kstack);
 
 	context_restore(&THREAD->saved_context);
@@ -363,10 +363,10 @@
 
 	/*
-	 * Through the 'THE' structure, we keep track of THREAD, TASK, CPU, AS
-	 * and preemption counter. At this point THE could be coming either
+	 * Through the 'CURRENT' structure, we keep track of THREAD, TASK, CPU, AS
+	 * and preemption counter. At this point CURRENT could be coming either
 	 * from THREAD's or CPU's stack.
 	 *
Index: kernel/generic/src/proc/the.c
===================================================================
--- kernel/generic/src/proc/the.c	(revision 174156fd1cf321a6363777352073d05829467b2f)
+++ kernel/generic/src/proc/the.c	(revision 91a8f837283629418f6b227ac9232dd63901abf2)
@@ -33,8 +33,8 @@
 /**
  * @file
  * @brief THE structure functions.
  *
  * This file contains functions to manage the THE structure.
  * The THE structure exists at the base address of every kernel
  * stack and carries information about current settings
  * (e.g. current CPU, current thread, task and address space
@@ -45,12 +45,12 @@
 #include <assert.h>
 
 /** Initialize THE structure
  *
  * Initialize THE structure passed as argument.
  *
  * @param the THE structure to be initialized.
  *
  */
-void the_initialize(the_t *the)
+void current_initialize(current_t *the)
 {
 	the->preemption = 0;
@@ -65,13 +65,13 @@
 }
 
 /** Copy THE structure
  *
  * Copy the source THE structure to the destination THE structure.
  *
  * @param src The source THE structure.
  * @param dst The destination THE structure.
  *
  */
-NO_TRACE void the_copy(the_t *src, the_t *dst)
+NO_TRACE void current_copy(current_t *src, current_t *dst)
 {
 	assert(src->magic == MAGIC);
@@ -33,8 +33,8 @@
 /**
  * @file
- * @brief THE structure functions.
+ * @brief CURRENT structure functions.
  *
@@ -33,8 +33,8 @@
  *
- * This file contains functions to manage the THE structure.
- * The THE structure exists at the base address of every kernel
+ * This file contains functions to manage the CURRENT structure.
+ * The CURRENT structure exists at the base address of every kernel
  * stack and carries information about current settings
  * (e.g. current CPU, current thread, task and address space
@@ -45,12 +45,12 @@
 #include <assert.h>
 
-/** Initialize THE structure
+/** Initialize CURRENT structure
  *
@@ -45,12 +45,12 @@
  *
- * Initialize THE structure passed as argument.
+ * Initialize CURRENT structure passed as argument.
  *
@@ -45,12 +45,12 @@
  *
- * @param the THE structure to be initialized.
+ * @param the CURRENT structure to be initialized.
  *
  */
@@ -65,13 +65,13 @@
 }
 
-/** Copy THE structure
+/** Copy CURRENT structure
  *
@@ -65,13 +65,13 @@
  *
- * Copy the source THE structure to the destination THE structure.
+ * Copy the source CURRENT structure to the destination CURRENT structure.
  *
@@ -65,13 +65,13 @@
  *
- * @param src The source THE structure.
- * @param dst The destination THE structure.
+ * @param src The source CURRENT structure.
+ * @param dst The destination CURRENT structure.
  *
  */